
![Python package](https://github.com/WagnerGroup/pyqmc/workflows/Python%20package/badge.svg)
[![Documentation Status](https://readthedocs.org/projects/pyqmc/badge/?version=latest)](https://pyqmc.readthedocs.io/en/latest/?badge=latest)
[![Gitter chat](https://badges.gitter.im/gitterHQ/gitter.png)](https://gitter.im//pyqmc/community)

## PyQMC

A python module that implements real-space quantum Monte Carlo techniques. It is primarily meant to interoperate with PySCF. Documentation is available at [readthedocs](https://pyqmc.readthedocs.io/en/latest/).

